﻿using System.Drawing;

using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraGrid.Views.Base;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.gridView.InitializeView
            (
                true,                          // Multi Select
                GridMultiSelectMode.RowSelect, // Grid Multi Select Mode
                DrawFocusRectStyle.CellFocus,  // Draw Focus Rect Style
                true,                          // Show Indicator
                true,                          // Show Column Headers
                true,                          // Allow Column Moving
                true,                          // Allow Column Resizing
                true,                          // Allow Filter
                true,                          // Allow Sort
                false,                         // Allow Cell Merge
                EditorShowMode.Default,        // Editor Show Mode
                false                          // Editable
            );
            
            this.gridView.OptionsBehavior.AutoPopulateColumns = true;

            this.gridView.OptionsView.ShowPreview = true;

            this.gridView.PreviewFieldName = "Title";
            this.gridView.PreviewLineCount = 2;

            this.gridControl.DataSource = new nwindDataSetTableAdapters.EmployeesTableAdapter().GetData();

            this.gridView.Columns["Title"].Visible = false;

            this.gridView.CustomDrawRowPreview += gridView_CustomDrawRowPreview;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 그리드 뷰 행 프리뷰 커스텀 그리기 - gridView_CustomDrawRowPreview(sender, e)

        /// <summary>
        /// 그리드 뷰 행 프리뷰 커스텀 그리기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridView_CustomDrawRowPreview(object sender, RowObjectCustomDrawEventArgs e)
        {
            GridView gridView = sender as GridView;

            if(e.RowHandle % 2 == 0)
            {
                int deltaX = 5;

                Rectangle rectangle = e.Bounds;

                rectangle.X     +=  e.Bounds.Height + deltaX * 2;
                rectangle.Width -= (e.Bounds.Height + deltaX * 3);

                e.Cache.FillRectangle(Color.Coral, new Rectangle(e.Bounds.X + deltaX, e.Bounds.Y, e.Bounds.Height, e.Bounds.Height));

                e.Appearance.ForeColor = Color.Green;

                e.Appearance.DrawString(e.Cache, gridView.GetRowPreviewDisplayText(e.RowHandle), rectangle);

                e.Handled = true;
            }
        }

        #endregion
    }
}